@@ -23,16 +23,23 @@
 #ifndef EV_APPLICATION_H
 #define EV_APPLICATION_H
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <glib/gerror.h>
 #include <glib-object.h>
 
+#ifdef WITH_GTK_PRINT
+#include <gtk/gtkprintsettings.h>
+#endif
+
 #include "ev-window.h"
 
 #include "egg-toolbars-model.h"
 #ifndef HAVE_GTK_RECENT
 #include "egg-recent-model.h"
 #endif
-#include "totem-scrsaver.h"
 
 G_BEGIN_DECLS
 
@@ -48,28 +55,7 @@ typedef struct _EvApplicationClass EvApplicationClass;
 
 #define EV_APP					(ev_application_get_instance ())
 
-struct _EvApplication {
-	GObject base_instance;
-	
-	gchar *toolbars_file;
-	
-	EggToolbarsModel *toolbars_model;
-	EggToolbarsModel *preview_toolbars_model;
-	
-#ifndef HAVE_GTK_RECENT
-	EggRecentModel  *recent_model;
-#endif
-
-	TotemScrsaver *scr_saver;
-	
-	gchar *last_chooser_uri;
-};
-
-struct _EvApplicationClass {
-	GObjectClass base_class;
-};
-
-GType	          ev_application_get_type	     (void);
+GType	          ev_application_get_type	     (void) G_GNUC_CONST;
 EvApplication    *ev_application_get_instance        (void);
 gboolean          ev_application_register_service    (EvApplication   *application);
 void	          ev_application_shutdown	     (EvApplication   *application);
@@ -90,6 +76,7 @@ void              ev_application_open_uri_at_dest    (EvApplication   *applicati
 						      EvLinkDest      *dest,
 						      EvWindowRunMode  mode,
 						      gboolean         unlink_temp_file,
+						      const gchar     *print_settings, 
 						      guint32          timestamp);
 void	          ev_application_open_uri_list       (EvApplication   *application,
 		  			              GSList          *uri_list,
@@ -97,8 +84,7 @@ void	          ev_application_open_uri_list       (EvApplication   *application,
     						      guint32          timestamp);
 GList		 *ev_application_get_windows	     (EvApplication   *application);
 
-EggToolbarsModel *ev_application_get_toolbars_model  (EvApplication   *application, 
-						      gboolean preview);
+EggToolbarsModel *ev_application_get_toolbars_model  (EvApplication   *application);
 void              ev_application_save_toolbars_model (EvApplication   *application);
 #ifndef HAVE_GTK_RECENT
 EggRecentModel   *ev_application_get_recent_model    (EvApplication   *application);
@@ -108,6 +94,12 @@ void 		  ev_application_set_chooser_uri     (EvApplication   *application,
 const gchar	 *ev_application_get_chooser_uri     (EvApplication   *application);
 void		  ev_application_screensaver_enable  (EvApplication   *application);
 void		  ev_application_screensaver_disable (EvApplication   *application);
+#ifdef WITH_GTK_PRINT
+GtkPrintSettings *ev_application_get_print_settings  (EvApplication   *application);
+void              ev_application_set_print_settings  (EvApplication   *application,
+						      GtkPrintSettings *settings);
+#endif
+
 G_END_DECLS
 
 #endif /* !EV_APPLICATION_H */
